@@ -5,7 +5,7 @@
 #	Name:
 #		GIFgraph::axestype.pm
 #
-# $Id: axestype.pm,v 2.3 1998/08/18 03:15:26 mgjv Exp $
+# $Id: axestype.pm,v 2.5 1998/08/25 23:28:41 mgjv Exp mgjv $
 #
 #==========================================================================
 
@@ -31,6 +31,7 @@ my %Defaults = (
 	# Number of ticks for the y axis
  
 	y_tick_number		=> 5,
+	x_tick_number		=> undef,		# CONTRIB Scott Prahl
  
 	# Skip every nth label. if 1 will print every label on the axes,
 	# if 2 will print every second, etc..
@@ -91,9 +92,10 @@ my %Defaults = (
 	legend_spacing			=> 4,
 	legend_placement		=> 'BC',		# '[B][LCR]'
 
-	# Format of the numbers on the y axis
+	# Format of the numbers on the x and y axis
 
 	y_number_format			=> undef,
+	x_number_format			=> undef,		# CONTRIB Scott Prahl
 );
 
 {
@@ -114,7 +116,7 @@ my %Defaults = (
 		$self->draw_data($self->{graph}, $data);
 		$self->draw_legend($self->{graph});
 
-		return $self->{graph}->gif;
+		return $self->{graph}->gif
 	}
 
 	sub set_x_label_font($) # (fontname)
@@ -218,14 +220,8 @@ my %Defaults = (
 		$s->set( ylfh1 => $s->{y1_label} ? 1 : 0 );
 		$s->set( ylfh2 => $s->{y2_label} ? 1 : 0 );
 
-		unless ( $s->{x_plot_values} ) 
-		{ 
-			$s->set( xafh => 0, xafw => 0 ); 
-		}
-		unless ( $s->{y_plot_values} ) 
-		{
-			$s->set( yafh => 0, yafw => 0 );
-		}
+		$s->set( xafh => 0, xafw => 0 ) unless ($s->{x_plot_values}); 
+		$s->set( yafh => 0, yafw => 0 ) unless ($s->{y_plot_values});
 
 		$s->{x_axis_label_height} = $s->get_x_axis_label_height($data);
 
@@ -235,12 +231,11 @@ my %Defaults = (
 		$s->{bottom} = 
 			$s->{gify} - $s->{b_margin} - 1 -
 			( $s->{xlfh} ? $s->{xlfh} : 0 ) -
-			( $s->{x_axis_label_height} ? $s->{x_axis_label_height}: 0) -
-			( $lbl ? $lbl * $s->{text_space} : 0 )
-		;
+			( $s->{x_axis_label_height} ? $s->{x_axis_label_height} : 0) -
+			( $lbl ? $lbl * $s->{text_space} : 0 );
 
 		$s->{top} = $s->{t_margin} +
-					( ( $s->{tfh} ) ? $s->{tfh} + $s->{text_space} : 0 );
+					( $s->{tfh} ? $s->{tfh} + $s->{text_space} : 0 );
 		$s->{top} = $s->{yafh}/2 if ( $s->{top} == 0 );
  
 		$s->set_max_min($data);
@@ -248,22 +243,45 @@ my %Defaults = (
 		# Create the labels for the y_axes, and calculate the max length
 
 		$s->create_y_labels();
+		$s->create_x_labels(); # CONTRIB Scott Prahl
 
 		# calculate the left and right of the bounding box for the graph
 		my $ls = $s->{yafw} * $s->{y_label_len}[1];
 		$s->{left} = $s->{l_margin} +
-					 ( ( $ls ) ? $ls + $s->{axis_space} : 0 ) +
-					 ( ( $s->{ylfh1} ) ? $s->{ylfh}+$s->{text_space} : 0 );
+					 ( $ls ? $ls + $s->{axis_space} : 0 ) +
+					 ( $s->{ylfh1} ? $s->{ylfh} + $s->{text_space} : 0 );
 
 		$ls = $s->{yafw} * $s->{y_label_len}[2] if $s->{two_axes};
 		$s->{right} = $s->{gifx} - $s->{r_margin} - 1 -
-					  $s->{two_axes}* (
-						  ( ( $ls ) ? $ls + $s->{axis_space} : 0 ) +
-						  ( ( $s->{ylfh2} ) ? $s->{ylfh}+$s->{text_space} : 0 )
+					  $s->{two_axes} * (
+						  ( $ls ? $ls + $s->{axis_space} : 0 ) +
+						  ( $s->{ylfh2} ? $s->{ylfh} + $s->{text_space} : 0 )
 					  );
+
+		# CONTRIB Scott Prahl
+		# make sure that we can generate valid x tick marks
+		undef($s->{x_tick_number}) if $s->{numpoints} < 2;
+		undef($s->{x_tick_number}) if (
+				!defined $s->{x_max} || 
+				!defined $s->{x_min} ||
+				$s->{x_max} == $s->{x_min}
+			);
  
 		# calculate the step size for x data
-		$s->{x_step} = ($s->{right}-$s->{left})/($s->{numpoints} + 2);
+		# CONTRIB Changes by Scott Prahl
+		if (defined $s->{x_tick_number})
+		{
+			my $delta = ($s->{right}-$s->{left})/($s->{x_max}-$s->{x_min});
+			$s->{x_offset} = 
+				($s->{true_x_min} - $s->{x_min}) * $delta + $s->{left};
+			$s->{x_step} = 
+				($s->{true_x_max} - $s->{true_x_min}) * $delta/$s->{numpoints};
+		}
+		else
+		{
+			$s->{x_step} = ($s->{right} - $s->{left})/($s->{numpoints} + 2);
+			$s->{x_offset} = $s->{left};
+		}
  
 		# get the zero axis level
 		my $dum;
@@ -282,9 +300,9 @@ my %Defaults = (
 		) unless ( exists $s->{dclrs} );
  
 		# More sanity checks
-		$s->{x_label_skip} = 1 if ( $s->{x_label_skip} < 1 );
-		$s->{y_label_skip} = 1 if ( $s->{y_label_skip} < 1 );
-		$s->{y_tick_number} = 1 if ( $s->{y_tick_number} < 1 );
+		$s->{x_label_skip} = 1 		if ( $s->{x_label_skip} < 1 );
+		$s->{y_label_skip} = 1 		if ( $s->{y_label_skip} < 1 );
+		$s->{y_tick_number} = 1		if ( $s->{y_tick_number} < 1 );
 	}
 
 	sub create_y_labels
@@ -295,7 +313,7 @@ my %Defaults = (
 		$s->{y_label_len}[2] = 0;
 
 		my $t;
-		foreach $t (0..$s->{y_tick_number})
+		foreach $t (0 .. $s->{y_tick_number})
 		{
 			my $a;
 			foreach $a (1 .. ($s->{two_axes} + 1))
@@ -329,6 +347,44 @@ my %Defaults = (
 		}
 	}
 
+	# CONTRIB Scott Prahl
+	sub create_x_labels
+	{
+		my $s = shift;
+		return unless defined($s->{x_tick_number});
+
+		$s->{x_label_len} = 0;
+
+		my $t;
+		foreach $t (0..$s->{x_tick_number})
+		{
+			my $label =
+				$s->{x_min} +
+				$t * ($s->{x_max} - $s->{x_min})/$s->{x_tick_number};
+
+			$s->{x_values}[$t] = $label;
+
+			if (defined $s->{x_number_format})
+			{
+				if (ref $s->{x_number_format} eq 'CODE')
+				{
+					$label = &{$s->{x_number_format}}($label);
+				}
+				else
+				{
+					$label = sprintf($s->{x_number_format}, $label);
+				}
+			}
+
+			my $len = length($label);
+
+			$s->{x_labels}[$t] = $label;
+
+			($len > $s->{x_label_len}) and $s->{x_label_len} = $len;
+		}
+	}
+
+
 	sub get_x_axis_label_height
 	{
 		my $s = shift;
@@ -345,7 +401,7 @@ my %Defaults = (
 			($llen > $len) and $len = $llen;
 		}
 
-		return $len * $s->{xafw};
+		return $len * $s->{xafw}
 	}
  
 	# inherit open_graph from GIFgraph
@@ -430,8 +486,11 @@ my %Defaults = (
 			$g->line($l, $y, $r, $y, $s->{fgci});
 		}
 	}
- 
-	sub draw_ticks($$) # GD::Image, \@data
+
+	#
+	# Ticks and values for y axes
+	#
+	sub draw_y_ticks($$) # GD::Image, \@data
 	{
 		my $s = shift;
 		my $g = shift;
@@ -441,7 +500,7 @@ my %Defaults = (
 		# Ticks and values for y axes
 		#
 		my $t;
-		foreach $t (0..$s->{y_tick_number}) 
+		foreach $t (0 .. $s->{y_tick_number}) 
 		{
 			my $a;
 			foreach $a (1 .. ($s->{two_axes} + 1)) 
@@ -449,11 +508,14 @@ my %Defaults = (
 				my $value = $s->{y_values}[$a][$t];
 				my $label = $s->{y_labels}[$a][$t];
 				
-				my ($x, $y) = $s->val_to_pixel( 
-					($a-1) * ($s->{numpoints} + 2), 
-					$value, 
-					$a 
-				);
+				my ($x, $y) = $s->val_to_pixel(0, $value, $a);
+				#my ($x, $y) = $s->val_to_pixel( 
+				#	($a-1) * ($s->{numpoints} + 2), 
+				#	$value, 
+				#	$a 
+				#);
+
+				$x = ($a == 1) ? $s->{left} : $s->{right};
 
 				if ($s->{long_ticks}) 
 				{
@@ -467,13 +529,13 @@ my %Defaults = (
 				{
 					$g->line( 
 						$x, $y, 
-						$x + (3-2*$a)*$s->{tick_length}, $y, 
+						$x + (3 - 2 * $a) * $s->{tick_length}, $y, 
 						$s->{fgci} 
 					);
 				}
 
 				next 
-					if ( $t%($s->{y_label_skip}) || ! $s->{y_plot_values} );
+					if ( $t % ($s->{y_label_skip}) || ! $s->{y_plot_values} );
 
 				$x -=
 					(2-$a) * length($label) * $s->{yafw} + 
@@ -482,19 +544,26 @@ my %Defaults = (
 				$g->string($s->{yaf}, $x, $y, $label, $s->{alci});
 			}
 		}
+	}
 
-		return 
-			unless ( $s->{x_plot_values} );
+	#
+	# Ticks and values for x axes
+	#
+	sub draw_x_ticks($$) # GD::Image, \@data
+	{
+		my $s = shift;
+		my $g = shift;
+		my $d = shift;
 
 		#
 		# Ticks and values for X axis
 		#
 		my $i;
-		for $i (0.. $s->{numpoints}) 
+		for $i (0 .. $s->{numpoints}) 
 		{
 			my ($x, $y) = $s->val_to_pixel($i + 1, 0, 1);
 
-			$y = $s->{bottom} unless ($s->{zero_axis_only});
+			$y = $s->{bottom} unless $s->{zero_axis_only};
 
 			next 
 				if ( !$s->{x_all_ticks} and 
@@ -524,17 +593,93 @@ my %Defaults = (
 			{
 				$x -= $s->{xafw};
 				my $yt = 
-					$y + $s->{text_space}/2 + $s->{xafw} * length($$d[0][$i]);
-				$g->stringUp($s->{xaf}, $x, $yt, $$d[0][$i], $s->{alci});
+					$y + $s->{text_space}/2 + $s->{xafw} * length($d->[0][$i]);
+				$g->stringUp($s->{xaf}, $x, $yt, $d->[0][$i], $s->{alci});
 			}
 			else
 			{
-				$x -= $s->{xafw} * length($$d[0][$i])/2;
+				$x -= $s->{xafw} * length($d->[0][$i])/2;
 				my $yt = $y + $s->{text_space}/2;
-				$g->string($s->{xaf}, $x, $yt, $$d[0][$i], $s->{alci});
+				$g->string($s->{xaf}, $x, $yt, $d->[0][$i], $s->{alci});
 			}
 		}
 	}
+
+	
+	# CONTRIB Scott Prahl
+	# Assume x array contains equally spaced x-values
+	# and generate an appropriate axis
+	#
+	sub draw_x_ticks_number($$) # GD::Image, \@data
+	{
+		my $s = shift;
+		my $g = shift;
+		my $d = shift;
+
+		my $i;
+		for $i (0 .. $s->{x_tick_number})
+		{
+			my $value = $s->{numpoints}
+						* ($s->{x_values}[$i] - $s->{true_x_min})
+			            / ($s->{true_x_max} - $s->{true_x_min});
+
+			my $label = $s->{x_values}[$i];
+
+			my ($x, $y) = $s->val_to_pixel($value + 1, 0, 1);
+
+			$y = $s->{bottom} unless $s->{zero_axis_only};
+
+			if ($s->{x_ticks})
+			{
+				if ($s->{long_ticks})
+				{
+					$g->line($x, $s->{bottom}, $x, $s->{top},$s->{fgci});
+				}
+				else
+				{
+					$g->line( $x, $y, $x, $y - $s->{tick_length}, $s->{fgci} );
+				}
+			}
+
+			next
+				if ( $i%($s->{x_label_skip}) and $i != $s->{x_tick_number} );
+
+			if ($s->{x_labels_vertical})
+			{
+				$x -= $s->{xafw};
+				my $yt =
+					$y + $s->{text_space}/2 + $s->{xafw} * length($d->[0][$i]);
+				$g->stringUp($s->{xaf}, $x, $yt, $label, $s->{alci});
+			}
+			else
+			{
+#				$x -= $s->{xafw} * length($$d[0][$i])/2;
+				$x -=  length($d->[0][$i])/2;
+				my $yt = $y + $s->{text_space}/2;
+				$g->string($s->{xaf}, $x, $yt, $label, $s->{alci});
+			}
+		}
+	}
+
+	sub draw_ticks($$) # GD::Image, \@data
+	{
+		my $s = shift;
+		my $g = shift;
+		my $d = shift;
+
+		$s->draw_y_ticks($g, $d);
+
+		return unless ( $s->{x_plot_values} );
+
+		if (defined $s->{x_tick_number})
+		{
+			$s->draw_x_ticks_number($g, $d);
+		}
+		else
+		{
+			$s->draw_x_ticks($g, $d);
+		}
+	}
  
 	sub draw_data($$) # GD::Image, \@data
 	{
@@ -545,7 +690,7 @@ my %Defaults = (
 		my $ds;
 		foreach $ds (1 .. $s->{numsets}) 
 		{
-			$s->draw_data_set($g, $$d[$ds], $ds);
+			$s->draw_data_set($g, $d->[$ds], $ds);
 		}
 	}
 
@@ -555,7 +700,7 @@ my %Defaults = (
 	{
 		# ABSTRACT
 		my $s = shift;
-		$s->die_abstract( "sub draw_data missing, ");
+		$s->die_abstract( "sub draw_data missing, ")
 	}
  
 	# Figure out the maximum values for the vertical exes, and calculate
@@ -573,60 +718,55 @@ my %Defaults = (
 		if ( $s->{two_axes} ) 
 		{
 			my $i;
-			for $i (1..2) 
+			for $i (1 .. 2) 
 			{
-				$s->{y_max}[$i] = up_bound( get_max_y(@{$$d[$i]}) );
-				$s->{y_min}[$i] = down_bound( get_min_y(@{$$d[$i]}) );
+				my $true_y_min = get_min_y(@{$$d[$i]});
+				my $true_y_max = get_max_y(@{$$d[$i]});
+				($s->{y_min}[$i], $s->{y_max}[$i], $s->{y_tick_number}) =
+					_best_ends($true_y_min, $true_y_max, $s->{y_tick_number});
 			}
 		} 
 		else 
 		{
-			@max_min = $s->get_max_min_y_all($d);
-			$s->{y_max}[1] = up_bound( $max_min[0] );
-			$s->{y_min}[1] = down_bound( $max_min[1] );
+			my ($true_y_min, $true_y_max) = $s->get_max_min_y_all($d);
+			($s->{y_min}[1], $s->{y_max}[1], $s->{y_tick_number}) =
+				_best_ends($true_y_min, $true_y_max, $s->{y_tick_number});
+		}
+
+		if (defined( $s->{x_tick_number} ))
+		{
+			$s->{true_x_min} = get_min_y(@{$d->[0]});
+			$s->{true_x_max} = get_max_y(@{$d->[0]});
+
+			($s->{x_min}, $s->{x_max}, $s->{x_tick_number}) =
+				_best_ends( $s->{true_x_min}, $s->{true_x_max}, 
+							$s->{x_tick_number});
 		}
 
 		# Make sure bars and area always have a zero offset
 
-		if ($s->{y_min}[1] >= 0)
+		if (ref($s) eq 'GIFgraph::bars' or ref($s) eq 'GIFgraph::area')
 		{
-			if (ref($s) eq 'GIFgraph::bars' or ref($s) eq 'GIFgraph::area')
-			{
-				$s->{y_min}[1] = 0; 
-			}
+			$s->{y_min}[1] = 0 if $s->{y_min}[1] > 0;
+			$s->{y_min}[2] = 0 if $s->{y_min}[2] && $s->{y_min}[2] > 0;
 		}
 
 		# Overwrite these with any user supplied ones
 
-		if ( defined $s->{y_min_value} ) 
-		{
-			my $i;
-			for $i (1 .. 2)
-			{
-				$s->{y_min}[$i] = $s->{y_min_value};
-			}
-		}
+		$s->{y_min}[1] = $s->{y_min_value}  if defined $s->{y_min_value};
+		$s->{y_min}[2] = $s->{y_min_value}  if defined $s->{y_min_value};
 
-		if ( defined $s->{y_max_value} ) 
-		{
-			my $i;
-			for $i (1 .. 2)
-			{
-				$s->{y_max}[$i] = $s->{y_max_value};
-			}
-		}
+		$s->{y_max}[1] = $s->{y_max_value}  if defined $s->{y_max_value};
+		$s->{y_max}[2] = $s->{y_max_value}  if defined $s->{y_max_value};
 
-		$s->{y_min}[1] = $s->{y1_min_value}
-			if ( $s->{y1_min_value} );
+		$s->{y_min}[1] = $s->{y1_min_value} if defined $s->{y1_min_value};
+		$s->{y_max}[1] = $s->{y1_max_value} if defined $s->{y1_max_value};
 
-		$s->{y_max}[1] = $s->{y1_max_value}
-			if ( $s->{y1_max_value} );
+		$s->{y_min}[2] = $s->{y2_min_value} if defined $s->{y2_min_value};
+		$s->{y_max}[2] = $s->{y2_max_value} if defined $s->{y2_max_value};
 
-		$s->{y_min}[2] = $s->{y2_min_value}
-			if ( $s->{y2_min_value} );
-
-		$s->{y_max}[2] = $s->{y2_max_value}
-			if ( $s->{y2_max_value} );
+		$s->{x_min}    = $s->{x_min_value}  if defined $s->{x_min_value};
+		$s->{x_max}    = $s->{x_max_value}  if defined $s->{x_max_value};
 
 		# Check to see if we have sensible values
 
@@ -636,18 +776,18 @@ my %Defaults = (
 			for $i (1 .. 2)
 			{
 				die "Minimum for y" . $i . " too large\n"
-					if ( $s->{y_min}[$i] > get_min_y(@{$$d[$i]}) );
+					if ( $s->{y_min}[$i] > get_min_y(@{$d->[$i]}) );
 				die "Maximum for y" . $i . " too small\n"
-					if ( $s->{y_max}[$i] < get_max_y(@{$$d[$i]}) );
+					if ( $s->{y_max}[$i] < get_max_y(@{$d->[$i]}) );
 			}
 		} 
-		else 
-		{
-			die "Minimum for y too large\n"
-				if ( $s->{y_min}[1] > $max_min[1] );
-			die "Maximum for y too small\n"
-				if ( $s->{y_max}[1] < $max_min[0] );
-		}
+#		else 
+#		{
+#			die "Minimum for y too large\n"
+#				if ( $s->{y_min}[1] > $max_min[1] );
+#			die "Maximum for y too small\n"
+#				if ( $s->{y_max}[1] < $max_min[0] );
+#		}
 	}
  
 	# return maximum value from an array
@@ -659,11 +799,11 @@ my %Defaults = (
 		my $i;
 		foreach $i (@_) 
 		{ 
-			next if (!defined($i));
+			next unless defined $i;
 			$max = (defined($max) && $max >= $i) ? $max : $i; 
 		}
 
-		return $max;
+		return $max
 	}
 
 	sub get_min_y(@) # array
@@ -673,11 +813,11 @@ my %Defaults = (
 		my $i;
 		foreach $i (@_) 
 		{ 
-			next if (!defined($i));
+			next unless defined $i;
 			$min = ( defined($min) and $min <= $i) ? $min : $i;
 		}
 
-		return $min;
+		return $min
 	}
  
 	# get maximum y value from the whole data set
@@ -693,14 +833,14 @@ my %Defaults = (
 		if ($s->{overwrite} == 2) 
 		{
 			my $i;
-			for $i (0..$s->{numpoints}) 
+			for $i (0 .. $s->{numpoints}) 
 			{
 				my $sum = 0;
 
 				my $j;
-				for $j (1..$s->{numsets}) 
+				for $j (1 .. $s->{numsets}) 
 				{ 
-					$sum += $$d[$j][$i]; 
+					$sum += $d->[$j][$i]; 
 				}
 
 				$max = _max( $max, $sum );
@@ -712,48 +852,77 @@ my %Defaults = (
 			my $i;
 			for $i ( 1 .. $s->{numsets} ) 
 			{
-				$max = _max( $max, get_max_y(@{$$d[$i]}) );
-				$min = _min( $min, get_min_y(@{$$d[$i]}) );
+				$max = _max( $max, get_max_y(@{$d->[$i]}) );
+				$min = _min( $min, get_min_y(@{$d->[$i]}) );
 			}
 		}
 
-		return ($max, $min);
-	}
- 
-	# Return a more or less nice top axis value, given a value
-	sub _bound($$) # value, offset
-	{
-		my $val = shift;
-		my $offset = shift;
-
-		my $ss = undef;
-		($val, $ss) = ($val >= 0) ? ($val, 1) : (-$val, -1);
-
-		return 0
-			if ($val == 0);
-
-		my $exp = 10**( int(log($val)/log(10)) );
-		my $ret = (int($val/$exp) + $offset) * $exp;
-
-		return $ss * $ret;
+		return ($max, $min)
 	}
 
-	sub up_bound($)
-	{
-		my $val = shift;
+	
+	# CONTRIB Scott Prahl
+	#
+	# Calculate best endpoints and number of intervals for an axis and
+	# returns ($nice_min, $nice_max, $n), where $n is the number of
+	# intervals and
+	#
+	#    $nice_min <= $min < $max <= $nice_max
+	#
+	# Usage:
+	#		($nmin,$nmax,$nint) = _best_ends(247, 508);
+	#		($nmin,$nmax) = _best_ends(247, 508, 5); 
+	# 			use 5 intervals
+	#		($nmin,$nmax,$nint) = _best_ends(247, 508, 4..7);	
+	# 			best of 4,5,6,7 intervals
 
-		my $offset = ($val < 0) ? -1 : 1;
+	sub _best_ends {
+		my ($min, $max, @n) = @_;
+		my ($best_min, $best_max, $best_num) = ($min, $max, 1);
 
-		return _bound($val, $offset);
-	}
+		# fix endpoints, fix intervals, set defaults
+		($min, $max) = ($max, $min) if ($min > $max);
+		($min, $max) = ($min) ? ($min * 0.5, $min * 1.5) : (-1,1) 
+			if ($max == $min);
 
-	sub down_bound($)
-	{
-		my $val = shift;
+		@n = (3..6) if (@n <= 0 || $n[0] =~ /auto/i);
 
-		my $offset = ($val < 0) ? 1 : -1;
+		my $best_fit = 1e30;
+		my $range = $max - $min;
 
-		return _bound($val, $offset);
+		# create array of interval sizes
+		my $s = 1;
+		while ($s < $range) { $s *= 10 }
+		while ($s > $range) { $s /= 10 }
+		my @step = map {$_ * $s} (0.2, 0.5, 1, 2, 5);
+
+		for (@n) 
+		{								
+			# Try all numbers of intervals
+			my $n = $_;
+			next if ($n < 1);
+
+			for (@step) 
+			{
+				next if ($n != 1) && ($_ < $range/$n); # $step too small
+
+				my $nice_min   = $_ * int($min/$_);
+				$nice_min  -= $_ if ($nice_min > $min);
+				my $nice_max   = ($n == 1) 
+					? $_ * int($max/$_ + 1) 
+					: $nice_min + $n * $_;
+				my $nice_range = $nice_max - $nice_min;
+
+				next if ($nice_max < $max);	# $nice_min too small
+				next if ($best_fit <= $nice_range - $range); # not closer fit
+
+				$best_min = $nice_min;
+				$best_max = $nice_max;
+				$best_fit = $nice_range - $range;
+				$best_num = $n;
+			}
+		}
+		return ($best_min, $best_max, $best_num)
 	}
 
 	# Convert value coordinates to pixel coordinates on the canvas.
@@ -772,9 +941,10 @@ my %Defaults = (
 		my $y_step = abs(($s->{bottom} - $s->{top})/($y_max - $y_min));
 
 		return ( 
-			_round( $s->{left} + $x * $s->{x_step} ),
+			_round( ($s->{x_tick_number} ? $s->{x_offset} : $s->{left}) 
+						+ $x * $s->{x_step} ),
 			_round( $s->{bottom} - ($y - $y_min) * $y_step )
-		);
+		)
 	}
 
 	#
@@ -915,7 +1085,7 @@ my %Defaults = (
 
 			my $xe = $x;	# position within an element
 
-			next if (!defined($legend) or $legend eq "");
+			next unless (defined($legend) && $legend ne "");
 
 			$s->draw_legend_marker($g, $i, $xe, $y);
 
@@ -960,7 +1130,6 @@ my %Defaults = (
 			$x + $s->{legend_marker_width}, $y + $s->{legend_marker_height},
 			$s->{acci}
 		);
-
 	}
 
 } # End of package GIFgraph::axestype
